@@ -41,7 +41,9 @@
 int main(int argc, char *argv [])
 {
   QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
   QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
 
   KLocalizedString::setApplicationDomain("kolourpaint");
 
